Class: Xberg::NodeContentComment

Inherits:
Data
  • Object
show all
Extended by:
T::Sig
Includes:
NodeContent
Defined in:
lib/xberg/native.rb

Overview

Reviewer/editor comment content (e.g. DOCX comments).

Distinct from [NodeContent::Footnote] (xberg-io/xberg#300): comments and footnotes both reach the internal document via a marker/definition pair, but a consumer needs to tell a reviewer comment apart from an authored footnote.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#textObject (readonly)

Returns the value of attribute text

Returns:

  • (Object)

    the current value of text



3912
3913
3914
# File 'lib/xberg/native.rb', line 3912

def text
  @text
end

Class Method Details

.from_hash(hash) ⇒ Object



3964
3965
3966
# File 'lib/xberg/native.rb', line 3964

def self.from_hash(hash)
  new(text: hash[:text] || hash["text"])
end

Instance Method Details

#admonition?Boolean

Returns:

  • (Boolean)


3956
# File 'lib/xberg/native.rb', line 3956

def admonition? = false

#citation?Boolean

Returns:

  • (Boolean)


3954
# File 'lib/xberg/native.rb', line 3954

def citation? = false

#code?Boolean

Returns:

  • (Boolean)


3934
# File 'lib/xberg/native.rb', line 3934

def code? = false

#comment?Boolean

Returns:

  • (Boolean)


3942
# File 'lib/xberg/native.rb', line 3942

def comment? = true

#definition_item?Boolean

Returns:

  • (Boolean)


3952
# File 'lib/xberg/native.rb', line 3952

def definition_item? = false

#definition_list?Boolean

Returns:

  • (Boolean)


3950
# File 'lib/xberg/native.rb', line 3950

def definition_list? = false

#footnote?Boolean

Returns:

  • (Boolean)


3940
# File 'lib/xberg/native.rb', line 3940

def footnote? = false

#formula?Boolean

Returns:

  • (Boolean)


3938
# File 'lib/xberg/native.rb', line 3938

def formula? = false

#group?Boolean

Returns:

  • (Boolean)


3944
# File 'lib/xberg/native.rb', line 3944

def group? = false

#heading?Boolean

Returns:

  • (Boolean)


3922
# File 'lib/xberg/native.rb', line 3922

def heading? = false

#image?Boolean

Returns:

  • (Boolean)


3932
# File 'lib/xberg/native.rb', line 3932

def image? = false

#list?Boolean

Returns:

  • (Boolean)


3926
# File 'lib/xberg/native.rb', line 3926

def list? = false

#list_item?Boolean

Returns:

  • (Boolean)


3928
# File 'lib/xberg/native.rb', line 3928

def list_item? = false

#metadata_block?Boolean

Returns:

  • (Boolean)


3960
3961
3962
# File 'lib/xberg/native.rb', line 3960

def  = false
# @param hash [Hash] deserialized from the native extension
# @return [self]

#page_break?Boolean

Returns:

  • (Boolean)


3946
# File 'lib/xberg/native.rb', line 3946

def page_break? = false

#paragraph?Boolean

Returns:

  • (Boolean)


3924
# File 'lib/xberg/native.rb', line 3924

def paragraph? = false

#quote?Boolean

Returns:

  • (Boolean)


3936
# File 'lib/xberg/native.rb', line 3936

def quote? = false

#raw_block?Boolean

Returns:

  • (Boolean)


3958
# File 'lib/xberg/native.rb', line 3958

def raw_block? = false

#slide?Boolean

Returns:

  • (Boolean)


3948
# File 'lib/xberg/native.rb', line 3948

def slide? = false

#table?Boolean

Returns:

  • (Boolean)


3930
# File 'lib/xberg/native.rb', line 3930

def table? = false

#title?Boolean

Returns:

  • (Boolean)


3920
# File 'lib/xberg/native.rb', line 3920

def title? = false