Module: Xberg::_Validator

Defined in:
sig/types.rbs

Instance Method Summary collapse

Instance Method Details

#validatevoid

This method returns an undefined value.

Optional methods the bridge calls when the object defines them (the trait's Rust default behavior applies otherwise): should_validate, priority. The lifecycle hooks initialize/shutdown are likewise optional (note: Ruby constructors are private and never count as the lifecycle hook).

Parameters:



2522
# File 'sig/types.rbs', line 2522

def validate: (ExtractedDocument result, ExtractionConfig config) -> void