Class: Xberg::ImageOutputFormatSvg

Inherits:
Data
  • Object
show all
Extended by:
T::Sig
Includes:
ImageOutputFormat
Defined in:
lib/xberg/native.rb

Overview

Output pure-vector SVG. Lossless. Raster sources are not re-encoded (a warning is emitted and the image bytes are left untouched).

When the source is already SVG, the bytes are passed through the usvg sanitizer (strips external hrefs, JS event handlers, and foreignObject elements) when [SvgOptions::sanitize] is true.

Requires the svg feature.

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.from_hash(hash) ⇒ Object



233
234
235
# File 'lib/xberg/native.rb', line 233

def self.from_hash(hash)
  new
end

Instance Method Details

#heif?Boolean

Returns:

  • (Boolean)


227
# File 'lib/xberg/native.rb', line 227

def heif? = false

#jpeg?Boolean

Returns:

  • (Boolean)


223
# File 'lib/xberg/native.rb', line 223

def jpeg? = false

#native?Boolean

Returns:

  • (Boolean)


219
# File 'lib/xberg/native.rb', line 219

def native? = false

#png?Boolean

Returns:

  • (Boolean)


221
# File 'lib/xberg/native.rb', line 221

def png? = false

#svg?Boolean

Returns:

  • (Boolean)


229
230
231
# File 'lib/xberg/native.rb', line 229

def svg? = true
# @param hash [Hash] deserialized from the native extension
# @return [self]

#webp?Boolean

Returns:

  • (Boolean)


225
# File 'lib/xberg/native.rb', line 225

def webp? = false