Class: Xberg::ImageOutputFormatSvg

Inherits:
Data
  • Object
show all
Extended by:
T::Sig
Includes:
ImageOutputFormat
Defined in:
lib/xberg/native.rb

Overview

Output pure-vector SVG. Lossless. Raster sources are not re-encoded (a warning is emitted and the image bytes are left untouched).

When the source is already SVG, the bytes are passed through the usvg sanitizer (strips external hrefs, JS event handlers, and foreignObject elements) when [SvgOptions::sanitize] is true.

Requires the svg feature.

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.from_hash(hash) ⇒ Object



222
223
224
# File 'lib/xberg/native.rb', line 222

def self.from_hash(hash)
  new
end

Instance Method Details

#heif?Boolean

Returns:

  • (Boolean)


216
# File 'lib/xberg/native.rb', line 216

def heif? = false

#jpeg?Boolean

Returns:

  • (Boolean)


212
# File 'lib/xberg/native.rb', line 212

def jpeg? = false

#native?Boolean

Returns:

  • (Boolean)


208
# File 'lib/xberg/native.rb', line 208

def native? = false

#png?Boolean

Returns:

  • (Boolean)


210
# File 'lib/xberg/native.rb', line 210

def png? = false

#svg?Boolean

Returns:

  • (Boolean)


218
219
220
# File 'lib/xberg/native.rb', line 218

def svg? = true
# @param hash [Hash] deserialized from the native extension
# @return [self]

#webp?Boolean

Returns:

  • (Boolean)


214
# File 'lib/xberg/native.rb', line 214

def webp? = false